==> vala-0.0.9.tar.bz2: vala-0.0.9/ccode/valaccodestatement.c <==
/* valaccodestatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valaccodestatement.h"

struct _ValaCCodeStatementPrivate {
};
#define VALA_CCODE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_STATEMENT, ValaCCodeStatementPrivate))
enum  {
	VALA_CCODE_STATEMENT_DUMMY_PROPERTY,
};
static gpointer vala_ccode_statement_parent_class = NULL;


static void vala_ccode_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeStatement * self = VALA_CCODE_STATEMENT (object);
	switch (property_id) {
	}
}


static void vala_ccode_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeStatement * self = VALA_CCODE_STATEMENT (object);
	switch (property_id) {
	}
}


static void vala_ccode_statement_class_init (ValaCCodeStatementClass * klass)
{
	vala_ccode_statement_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_statement_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_statement_set_property;
}


static void vala_ccode_statement_init (ValaCCodeStatement * self)
{
}


GType vala_ccode_statement_get_type ()
{
	static GType vala_ccode_statement_type_id = 0;
	if (G_UNLIKELY (vala_ccode_statement_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStatement), 0, (GInstanceInitFunc) vala_ccode_statement_init };
		vala_ccode_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeStatement", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	}
	return vala_ccode_statement_type_id;
}

==> vala-0.1.0.tar.bz2: vala-0.1.0/ccode/valaccodestatement.c <==
/* valaccodestatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valaccodestatement.h"

enum  {
	VALA_CCODE_STATEMENT_DUMMY_PROPERTY
};
static gpointer vala_ccode_statement_parent_class = NULL;


static void vala_ccode_statement_class_init (ValaCCodeStatementClass * klass)
{
	vala_ccode_statement_parent_class = g_type_class_peek_parent (klass);
}


static void vala_ccode_statement_init (ValaCCodeStatement * self)
{
}


GType vala_ccode_statement_get_type ()
{
	static GType vala_ccode_statement_type_id = 0;
	if (G_UNLIKELY (vala_ccode_statement_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStatement), 0, (GInstanceInitFunc) vala_ccode_statement_init };
		vala_ccode_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeStatement", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	}
	return vala_ccode_statement_type_id;
}
